@@ -36,7 +36,7 @@
 #' Further model details can be found in the source link below.
 #'
 #' In calls to \code{\link{varimp}} for \code{C50Model}, argument \code{metric}
-#' may be spedified as \code{"usage"} (default) for the percentage of training
+#' may be specified as \code{"usage"} (default) for the percentage of training
 #' set samples that fall into all terminal nodes after the split of each
 #' predictor or as \code{"splits"} for the percentage of splits associated with
 #' each predictor.  Variable importance is automatically scaled to range from 0
@@ -68,7 +68,7 @@ C50Model <- function(trials = 1, rules = FALSE, subset = TRUE, bands = 0,
     response_types = "factor",
     predictor_encoding = "terms",
     params = params,
-    grid = function(x, length, ...) {
+    grid = function(length, ...) {
       list(
         trials = c(1, round(seq_range(0, 10, c(2, 100), length))),
         rules = c(FALSE, TRUE),
