@@ -36,10 +36,10 @@
 #' @examples
 #' fit(Species ~ ., data = iris, model = LDAModel)
 #'
-LDAModel <- function(prior = NULL, tol = 1e-4,
-                     method = c("moment", "mle", "mve", "t"), nu = 5,
-                     dimen = NULL,
-                     use = c("plug-in", "debiased", "predictive")) {
+LDAModel <- function(
+  prior = NULL, tol = 1e-4, method = c("moment", "mle", "mve", "t"), nu = 5,
+  dimen = NULL, use = c("plug-in", "debiased", "predictive")
+) {
 
   method <- match.arg(method)
   use <- match.arg(use)
