@@ -30,12 +30,11 @@
 #' @examples
 #' fit(sale_amount ~ ., data = ICHomes, model = RandomForestModel)
 #'
-RandomForestModel <- function(ntree = 500,
-                              mtry = .(if (is.factor(y)) floor(sqrt(nvars))
-                                       else max(floor(nvars / 3), 1)),
-                              replace = TRUE,
-                              nodesize = .(if (is.factor(y)) 1 else 5),
-                              maxnodes = NULL) {
+RandomForestModel <- function(
+  ntree = 500,
+  mtry = .(if (is.factor(y)) floor(sqrt(nvars)) else max(floor(nvars / 3), 1)),
+  replace = TRUE, nodesize = .(if (is.factor(y)) 1 else 5), maxnodes = NULL
+) {
 
   MLModel(
     name = "RandomForestModel",
