@@ -29,9 +29,10 @@
 #' @examples
 #' fit(Species ~ ., data = iris, model = TreeModel)
 #'
-TreeModel <- function(mincut = 5, minsize = 10, mindev = 0.01,
-                      split = c("deviance", "gini"), k = NULL, best = NULL,
-                      method = c("deviance", "misclass")) {
+TreeModel <- function(
+  mincut = 5, minsize = 10, mindev = 0.01, split = c("deviance", "gini"),
+  k = NULL, best = NULL, method = c("deviance", "misclass")
+) {
 
   split <- match.arg(split)
   method <- if (is.null(k) && is.null(best)) NULL else match.arg(method)
